# AnyTraverse

Offroad traversability segmentation with VLMs and human-in-the-loop.

## Installation

### For `x86` and `amd64` Systems

```bash
pip install anytraverse   # For pip users
uv add anytraverse        # For uv users
```

It is recommended to use the [`uv` package manager](https://docs.astral.sh/uv/).

### For Embedded Systems and Other Architectures

Install the AnyTraverse package from the GitHub repo [using `uv`](https://docs.astral.sh/uv/pip/packages/#installing-a-package:~:text=ruff%20%40%20./projects/ruff%22-,To%20install%20a%20package%20from%20GitHub,-%3A)

```bash
uv add anytraverse @ git+https://github.com/sattwik-sahu/AnyTraverse.git
```

This will install AnyTraverse using the main branch of the git repository. For other branches, append `@<branch-name>` after the repo URL.

> For systems requiring special builds of torch (e.g. Jetson `aarch64` machines), install using the instructions for the specific machine after installing with the above command.

---

## Usage

_Coming soon..._

---

## Contributing

_Coming soon..._

---

Made with :heart: in IISER Bhopal.
